@@ -1,5 +1,3 @@
-#' @import bitops
-
 decode_line = function(encoded){
 
   vlen = nchar(encoded)
@@ -18,7 +16,7 @@ decode_line = function(encoded){
         vb = as.integer(charToRaw(substr(encoded, vindex, vindex))) - 63
       }
 
-      vresult = bitops::bitOr(vresult, bitShiftL(bitAnd(vb, 31), vshift))
+      vresult = bitops::bitOr(vresult, bitops::bitShiftL(bitops::bitAnd(vb, 31), vshift))
       vshift = vshift + 5
       if(vb < 32) break
     }
@@ -38,7 +36,7 @@ decode_line = function(encoded){
         vb = as.integer(charToRaw(substr(encoded, vindex, vindex))) - 63
       }
 
-      vresult = bitOr(vresult, bitops::bitShiftL(bitops::bitAnd(vb, 31), vshift))
+      vresult = bitops::bitOr(vresult, bitops::bitShiftL(bitops::bitAnd(vb, 31), vshift))
       vshift = vshift + 5
       if(vb < 32) break
     }
